@@ -20,11 +20,11 @@
 #include "curb_macros.h"
 
 // These should be managed from the Rake 'release' task.
-#define CURB_VERSION   "0.8.5"
-#define CURB_VER_NUM   805
+#define CURB_VERSION   "0.8.6"
+#define CURB_VER_NUM   806
 #define CURB_VER_MAJ   0
 #define CURB_VER_MIN   8
-#define CURB_VER_MIC   5
+#define CURB_VER_MIC   6
 #define CURB_VER_PATCH 0
 
 
@@ -37,12 +37,8 @@
   #define RSTRING_PTR(x) RSTRING(x)->ptr
 #endif
 
-#ifndef RHASH_LEN
-#ifdef HAVE_RUBY19_HASH
-  #define RHASH_LEN(hash) RHASH(hash)->ntbl->num_entries
-#else
-  #define RHASH_LEN(hash) RHASH(hash)->tbl->num_entries
-#endif
+#ifndef RHASH_SIZE
+  #define RHASH_SIZE(hash) RHASH(hash)->tbl->num_entries
 #endif
 
 extern VALUE mCurl;
