@@ -4,13 +4,17 @@
  *
  */
 #include "curb_config.h"
-#ifdef HAVE_RUBY19_ST_H
-  #include <ruby.h>
+#include <ruby.h>
+#ifdef HAVE_RUBY_ST_H
   #include <ruby/st.h>
 #else
-  #include <ruby.h>
   #include <st.h>
 #endif
+
+#ifdef HAVE_RB_THREAD_CALL_WITHOUT_GVL
+  #include <ruby/thread.h>
+#endif
+
 #include "curb_easy.h"
 #include "curb_errors.h"
 #include "curb_postfield.h"
@@ -64,7 +68,7 @@ rb_hash_clear_i(VALUE key, VALUE value, VALUE dummy) {
 
 static void curl_multi_free(ruby_curl_multi *rbcm) {
 
-  if (rbcm && !rbcm->requests == Qnil && rb_type(rbcm->requests) == T_HASH && RHASH_LEN(rbcm->requests) > 0) {
+  if (rbcm && !rbcm->requests == Qnil && rb_type(rbcm->requests) == T_HASH && RHASH_SIZE(rbcm->requests) > 0) {
 
     rb_hash_foreach( rbcm->requests, (int (*)())curl_multi_flush_easy, (VALUE)rbcm );
 
@@ -262,12 +266,9 @@ VALUE ruby_curl_multi_add(VALUE self, VALUE easy) {
  */
 VALUE ruby_curl_multi_remove(VALUE self, VALUE easy) {
   ruby_curl_multi *rbcm;
-  ruby_curl_easy *rbce;
 
   Data_Get_Struct(self, ruby_curl_multi, rbcm);
 
-  Data_Get_Struct(easy, ruby_curl_easy, rbce);
-
   rb_curl_multi_remove(rbcm,easy);
 
   return self;
@@ -471,7 +472,7 @@ void cleanup_crt_fd(fd_set *os_set, fd_set *crt_set)
 }
 #endif
 
-#ifdef HAVE_RB_THREAD_BLOCKING_REGION
+#if defined(HAVE_RB_THREAD_BLOCKING_REGION) || defined(HAVE_RB_THREAD_CALL_WITHOUT_GVL)
 struct _select_set {
   int maxfd;
   fd_set *fdread, *fdwrite, *fdexcep;
@@ -511,7 +512,7 @@ VALUE ruby_curl_multi_perform(int argc, VALUE *argv, VALUE self) {
   long timeout_milliseconds;
   struct timeval tv = {0, 0};
   VALUE block = Qnil;
-#ifdef HAVE_RB_THREAD_BLOCKING_REGION
+#if defined(HAVE_RB_THREAD_BLOCKING_REGION) || defined(HAVE_RB_THREAD_CALL_WITHOUT_GVL)
   struct _select_set fdset_args;
 #endif
 
@@ -570,17 +571,22 @@ VALUE ruby_curl_multi_perform(int argc, VALUE *argv, VALUE self) {
       create_crt_fd(&fdexcep, &crt_fdexcep);
 #endif
 
-#ifdef HAVE_RB_THREAD_BLOCKING_REGION
+#if defined(HAVE_RB_THREAD_BLOCKING_REGION) || defined(HAVE_RB_THREAD_CALL_WITHOUT_GVL)
       fdset_args.maxfd = maxfd+1;
       fdset_args.fdread = &fdread;
       fdset_args.fdwrite = &fdwrite;
       fdset_args.fdexcep = &fdexcep;
       fdset_args.tv = &tv;
+#ifdef HAVE_RB_THREAD_CALL_WITHOUT_GVL
+      rc = (int)(VALUE) rb_thread_call_without_gvl((void *(*)(void *))curb_select, &fdset_args, RUBY_UBF_IO, 0);
+#elif HAVE_RB_THREAD_BLOCKING_REGION
       rc = rb_thread_blocking_region(curb_select, &fdset_args, RUBY_UBF_IO, 0);
 #else
       rc = rb_thread_select(maxfd+1, &fdread, &fdwrite, &fdexcep, &tv);
 #endif
 
+#endif
+
 #ifdef _WIN32
       cleanup_crt_fd(&fdread, &crt_fdread);
       cleanup_crt_fd(&fdwrite, &crt_fdwrite);
