@@ -645,8 +645,8 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     curl = Curl::Easy.new(TestServlet.url)
     curl.multipart_form_post = true
     fields = [
-      Curl::PostField.file('foo', File.expand_path(File.join(File.dirname(__FILE__),'..','README'))),
-      Curl::PostField.file('bar', File.expand_path(File.join(File.dirname(__FILE__),'..','README')))
+      Curl::PostField.file('foo', File.expand_path(File.join(File.dirname(__FILE__),'..','README.markdown'))),
+      Curl::PostField.file('bar', File.expand_path(File.join(File.dirname(__FILE__),'..','README.markdown')))
     ]
     curl.http_post(fields)
     assert_match /HTTP POST file upload/, curl.body_str
@@ -674,7 +674,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
   def test_post_multipart_file_remote
     curl = Curl::Easy.new(TestServlet.url)
     curl.multipart_form_post = true
-    pf = Curl::PostField.file('readme', File.expand_path(File.join(File.dirname(__FILE__),'..','README')))
+    pf = Curl::PostField.file('readme', File.expand_path(File.join(File.dirname(__FILE__),'..','README.markdown')))
     curl.http_post(pf)
     assert_match /HTTP POST file upload/, curl.body_str
     assert_match /Content-Disposition: form-data/, curl.body_str
@@ -855,7 +855,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
   end
 
   def test_post_streaming
-    readme = File.expand_path(File.join(File.dirname(__FILE__),'..','README'))
+    readme = File.expand_path(File.join(File.dirname(__FILE__),'..','README.markdown'))
     
     pf = Curl::PostField.file("filename", readme)
 
@@ -1022,6 +1022,13 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     end
   end
 
+  def test_set_unsupported_options
+    curl = Curl::Easy.new
+    assert_raises TypeError do
+      curl.set(99999, 1)
+    end
+  end
+
   include TestServerMethods 
 
   def setup
